netapp_ontap.models.fc_switch_ports_attached_device API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fc_switch_ports_attached_device`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FcSwitchPortsAttachedDeviceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FcSwitchPortsAttachedDevice object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `port_id: str GET`

    The Fibre Channel port identifier of the attach device.

    Example: 70400

  `wwpn: str GET`

    The world-wide port name (WWPN) of the attached device.

    Example: 50:0a:21:22:23:24:25:26